==> swc-1.3.37.tar.gz: swc-1.3.37/crates/swc/tests/tsc-references/moduleWithStatementsOfEveryKind.1.normal.js <==
//// [moduleWithStatementsOfEveryKind.ts]
import _class_call_check from "@swc/helpers/src/_class_call_check.mjs";
import _inherits from "@swc/helpers/src/_inherits.mjs";
import _create_super from "@swc/helpers/src/_create_super.mjs";
var A;
(function(A) {
    var F = function F(s) {
        return 2;
    };
    var A1 = function A() {
        "use strict";
        _class_call_check(this, A);
    };
    var AA = function AA() {
        "use strict";
        _class_call_check(this, AA);
    };
    var B = /*#__PURE__*/ function(AA) {
        "use strict";
        _inherits(B, AA);
        var _super = _create_super(B);
        function B() {
            _class_call_check(this, B);
            return _super.apply(this, arguments);
        }
        return B;
    }(AA);
    var BB = /*#__PURE__*/ function(A) {
        "use strict";
        _inherits(BB, A);
        var _super = _create_super(BB);
        function BB() {
            _class_call_check(this, BB);
            return _super.apply(this, arguments);
        }
        return BB;
    }(A1);
    var Module;
    (function(Module) {
        var A = function A() {
            "use strict";
            _class_call_check(this, A);
        };
    })(Module || (Module = {}));
    var Color;
    (function(Color) {
        Color[Color["Blue"] = 0] = "Blue";
        Color[Color["Red"] = 1] = "Red";
    })(Color || (Color = {}));
    var x = 12;
    var array = null;
    var fn = function(s) {
        return "hello " + s;
    };
    var ol = {
        s: "hello",
        id: 2,
        isvalid: true
    };
})(A || (A = {}));
var Y;
(function(Y) {
    var F = function F(s) {
        return 2;
    };
    var A = function A() {
        "use strict";
        _class_call_check(this, A);
    };
    Y.A = A;
    var AA = function AA() {
        "use strict";
        _class_call_check(this, AA);
    };
    Y.AA = AA;
    var B = /*#__PURE__*/ function(AA) {
        "use strict";
        _inherits(B, AA);
        var _super = _create_super(B);
        function B() {
            _class_call_check(this, B);
            return _super.apply(this, arguments);
        }
        return B;
    }(AA);
    Y.B = B;
    var BB = /*#__PURE__*/ function(A) {
        "use strict";
        _inherits(BB, A);
        var _super = _create_super(BB);
        function BB() {
            _class_call_check(this, BB);
            return _super.apply(this, arguments);
        }
        return BB;
    }(A);
    Y.BB = BB;
    var Module;
    (function(Module) {
        var A = function A() {
            "use strict";
            _class_call_check(this, A);
        };
    })(Module = Y.Module || (Y.Module = {}));
    var Color;
    (function(Color) {
        Color[Color["Blue"] = 0] = "Blue";
        Color[Color["Red"] = 1] = "Red";
    })(Color = Y.Color || (Y.Color = {}));
    var x = Y.x = 12;
    Y.F = F;
    var array = Y.array = null;
    var fn = Y.fn = function(s) {
        return "hello " + s;
    };
    var ol = Y.ol = {
        s: "hello",
        id: 2,
        isvalid: true
    };
})(Y || (Y = {}));

==> swc-1.3.97.tar.gz: swc-1.3.97/crates/swc/tests/tsc-references/moduleWithStatementsOfEveryKind.1.normal.js <==
//// [moduleWithStatementsOfEveryKind.ts]
import { _ as _class_call_check } from "@swc/helpers/_/_class_call_check";
import { _ as _inherits } from "@swc/helpers/_/_inherits";
import { _ as _create_super } from "@swc/helpers/_/_create_super";
var A;
(function(A) {
    var A1 = function A() {
        "use strict";
        _class_call_check(this, A);
    };
    var AA = function AA() {
        "use strict";
        _class_call_check(this, AA);
    };
    var B = /*#__PURE__*/ function(AA) {
        "use strict";
        _inherits(B, AA);
        var _super = _create_super(B);
        function B() {
            _class_call_check(this, B);
            return _super.apply(this, arguments);
        }
        return B;
    }(AA);
    var BB = /*#__PURE__*/ function(A) {
        "use strict";
        _inherits(BB, A);
        var _super = _create_super(BB);
        function BB() {
            _class_call_check(this, BB);
            return _super.apply(this, arguments);
        }
        return BB;
    }(A1);
    var Module;
    (function(Module) {
        var A = function A() {
            "use strict";
            _class_call_check(this, A);
        };
    })(Module || (Module = {}));
    var Color;
    (function(Color) {
        Color[Color["Blue"] = 0] = "Blue";
        Color[Color["Red"] = 1] = "Red";
    })(Color || (Color = {}));
    var x = 12;
    function F(s) {
        return 2;
    }
    var array = null;
    var fn = function(s) {
        return "hello " + s;
    };
    var ol = {
        s: "hello",
        id: 2,
        isvalid: true
    };
})(A || (A = {}));
var Y;
(function(Y) {
    var A = function A() {
        "use strict";
        _class_call_check(this, A);
    };
    Y.A = A;
    var AA = function AA() {
        "use strict";
        _class_call_check(this, AA);
    };
    Y.AA = AA;
    var B = /*#__PURE__*/ function(AA) {
        "use strict";
        _inherits(B, AA);
        var _super = _create_super(B);
        function B() {
            _class_call_check(this, B);
            return _super.apply(this, arguments);
        }
        return B;
    }(AA);
    Y.B = B;
    var BB = /*#__PURE__*/ function(A) {
        "use strict";
        _inherits(BB, A);
        var _super = _create_super(BB);
        function BB() {
            _class_call_check(this, BB);
            return _super.apply(this, arguments);
        }
        return BB;
    }(A);
    Y.BB = BB;
    var Module;
    (function(Module) {
        var A = function A() {
            "use strict";
            _class_call_check(this, A);
        };
    })(Module = Y.Module || (Y.Module = {}));
    var Color;
    (function(Color) {
        Color[Color["Blue"] = 0] = "Blue";
        Color[Color["Red"] = 1] = "Red";
    })(Color = Y.Color || (Y.Color = {}));
    Y.x = 12;
    function F(s) {
        return 2;
    }
    Y.F = F;
    Y.array = null;
    Y.fn = function(s) {
        return "hello " + s;
    };
    Y.ol = {
        s: "hello",
        id: 2,
        isvalid: true
    };
})(Y || (Y = {}));
